"""Main CLI g-storm interface.

Enables building static-typed ORM models.
"""

import click
from . import scripts


@click.group()
def cli():
    pass


def main():
    cli.add_command(scripts.cleanup)
    cli.add_command(scripts.validate_schema)
    cli.add_command(scripts.build_classes)
    # cli.add_command(scripts.build_query)
    # cli.add_command(scripts.build_create)
    # cli.add_command(scripts.build_upsert)
    cli()


if __name__ == "__main__":
    main()



# from .gstorm import mainClass
from .__version__ import __version__
from . import cli
from . import helpers
from .BaseGraphQLType import BaseGraphQLType
from .GraphQLType import GraphQLType
from .QueryBuilder import QueryBuilder
from .MutationBuilder import MutationBuilder
from ._mutation_runners import (
    create,
    save_multi_create,
    update,
    upsert,
)

# * Package name:
name = 'gstorm'



from datetime import datetime
from pytz import timezone
from tzlocal import get_localzone as get_tz
from dateutil.parser import parse


def get_utc_date(date):
    utc = timezone('UTC')
    tz = get_tz()  # local timezone
    if not date.tzinfo:
        local_date = tz.localize(date)
    else:
        local_date = date
    utc_date = local_date.astimezone(utc)
    return utc_date


def get_local_date(date):
    tz = get_tz()
    if not date.tzinfo:  # if false, already localized, skip
        local_date = tz.localize(date)
    else:
        local_date = date
    return local_date


def iso8601_to_local_date(iso_str):
    if not type(iso_str) == str:
        return iso_str  # do nothing if not string, expect it to be a date already
    utc = timezone("UTC")
    utc_date = datetime.strptime(iso_str, "%Y-%m-%dT%H:%M:%SZ")
    utc_date = utc.localize(utc_date)
    tz = get_tz()
    return utc_date.astimezone(tz)


def get_iso8601_str(date):
    return date.strftime("%Y-%m-%dT%H:%M:%SZ")


def get_datetime_object(datetime, format_type):
    """This function returns a datetime object.

    Args:
        datetime (str): Datetime string
        format_type (str): datetime format

    Returns:
        object: Datetime object
    """
    datetime = parse(datetime)

    if format_type == "Time":
        return datetime.time()

    elif format_type == "Date":
        return datetime.date()

    else:
        return datetime



import os
from pygqlc import GraphQLClient


def setup_gql(env_name=None):
    env = env_name or os.environ.get('ENV')
    gql = GraphQLClient()
    gql.addEnvironment(
        env,
        url=os.environ.get('API'),
        wss=os.environ.get('WSS'),
        headers={'Authorization': os.environ.get('TOKEN')})
    # ! Sets the environment selected in the .env file
    gql.setEnvironment(env)
    return gql



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

from setuptools import setup, find_packages

# reference: https://stackoverflow.com/questions/458550/standard-way-to-embed-version-into-python-package#:~:text=should%20be%20placed%20after%20the,previous%20version%20of%20this%20standard).&text=It%20should%20be%20a%20string,version_info%20for%20the%20tuple%20version.


def get_package_version(version_file):
    import re
    verstrline = open(version_file, "rt").read()
    VSRE = r"^__version__ = ['\"]([^'\"]*)['\"]"
    mo = re.search(VSRE, verstrline, re.M)
    if mo:
        verstr = mo.group(1)
        return verstr
    else:
        raise RuntimeError(
            "Unable to find version string in %s." % (version_file,))


__version__ = get_package_version("gstorm/__version__.py")

requirements = [
    # TODO: put package requirements here
    'attrs==19.3.0',
    'click==7.1.2',
    'colorama==0.4.4',
    'inflect==5.3.0',
    'pydash==5.0.2',
    # the setup file doesnt allow ~= matches, so we use a range instead:
    # docs.python.org/3/distutils/setupscript.html
    'pygqlc>=3.0.1, <4.0.0',
    'python-dateutil==2.8.2',
    'pytz==2022.2.1',
    'termcolor==1.1.0',
    'tzlocal==4.2',
]

setup_requirements = [
    # TODO: put setup requirements (distutils extensions, etc.) here
    'twine'
]

test_requirements = [
    # TODO: put package test requirements here
    'pytest',
    'pytest-cov',
    'black'
]

desc = "GraphQL ORM for python (based on pygqlc)"
with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='gstorm',
    version=__version__,
    description=desc,
    long_description=long_description,
    long_description_content_type='text/markdown',
    author="Valiot",
    author_email="hiring@valiot.io",
    url='https://github.com/valiot/python-gstorm',
    packages=find_packages(include=['gstorm', 'gstorm.cli']),
    entry_points={
        'console_scripts': [
            'gstorm-cli=gstorm.cli.__main__:main'
        ]
    },
    include_package_data=True,
    install_requires=requirements,
    zip_safe=False,
    keywords=['gstorm', 'orm', 'graphql', 'gql'],
    test_suite='tests',
    tests_require=test_requirements,
    setup_requires=setup_requirements,
)
